@@ -37,6 +37,8 @@ def quantise(input_signal, depth, max_amp=1):
 def apply_adsr(input_signal, sustain_amp, attack, decay, release, shape=1, samplerate=None):
     samples, samplerate = get_samples_and_rate(input_signal, samplerate)
 
+    if sustain_amp < 0 or sustain_amp > 1:
+        raise ValueError('The sustain amplitude needs to be a value between 0 and 1')
     attack_size = round(attack * samplerate)
     decay_size = round(decay * samplerate)
     release_size = round(release * samplerate)
@@ -50,8 +52,10 @@ def apply_adsr(input_signal, sustain_amp, attack, decay, release, shape=1, sampl
     r = np.linspace(sustain_amp, 0, release_size)
     if shape:
         a = a ** (1/shape)
-        d = ((d - sustain_amp) / (1 - sustain_amp)) ** shape * (1 - sustain_amp) + sustain_amp
-        r = (r / sustain_amp) ** shape * sustain_amp
+        if sustain_amp != 1:
+            d = ((d - sustain_amp) / (1 - sustain_amp)) ** shape * (1 - sustain_amp) + sustain_amp
+        if sustain_amp != 0:
+            r = (r / sustain_amp) ** shape * sustain_amp
 
     adsr_curve = np.concatenate((a, d, s, r))
     return same_type_as(samples * adsr_curve, input_signal)
